pub struct WeakHandle { /* private fields */ }Expand description
Handle to an asset that does not prevent the asset from being unloaded.
Weak handles are primarily used when you want to use something that is already loaded.
For example, a strong handle to an asset may be guaranteed to exist elsewhere in the program, and so you can simply get and use a weak handle to that asset in other parts of your code. This removes reference counting overhead, but also ensures that the system which uses the weak handle is not in control of when to unload the asset.
Implementations
Sourceimpl WeakHandle
impl WeakHandle
pub fn new(handle: LoadHandle) -> Self